'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var pg = require('pg');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var pg__default = /*#__PURE__*/_interopDefaultLegacy(pg);

class PostgresConnection {
  constructor(dbUrl, sessionStorageIdentifier) {
    this.sessionStorageIdentifier = void 0;
    this.ready = void 0;
    this.client = void 0;
    this.ready = this.init(dbUrl);
    this.sessionStorageIdentifier = sessionStorageIdentifier;
  }
  async query(query, params = []) {
    await this.ready;
    return (await this.client.query(query, params)).rows;
  }
  async disconnect() {
    await this.ready;
    await this.client.end();
  }
  async connect() {
    await this.ready;
    await this.client.connect();
  }
  getDatabase() {
    return this.client.database;
  }
  async hasTable(tablename) {
    await this.ready;
    const query = `
      SELECT EXISTS (
        SELECT tablename FROM pg_catalog.pg_tables 
          WHERE tablename = ${this.getArgumentPlaceholder(1)}
      )
  `;

    // Allow multiple apps to be on the same host with separate DB and querying the right
    // DB for the session table exisitence
    const rows = await this.query(query, [tablename]);
    return rows[0].exists;
  }
  getArgumentPlaceholder(position) {
    return `$${position}`;
  }
  async init(dbUrl) {
    this.client = new pg__default["default"].Client({
      connectionString: dbUrl.toString()
    });
  }
}

exports.PostgresConnection = PostgresConnection;
