"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.migrateToCaseSensitivity = exports.migrateScopeFieldToVarchar1024 = exports.migrationList = void 0;
var tslib_1 = require("tslib");
var shopify_app_session_storage_1 = require("@shopify/shopify-app-session-storage");
exports.migrationList = [
    new shopify_app_session_storage_1.MigrationOperation('migrateScopeFieldToVarchar1024', migrateScopeFieldToVarchar1024),
    new shopify_app_session_storage_1.MigrationOperation('migrateToCaseSensitivity', migrateToCaseSensitivity),
];
// need change the size of the scope column from 255 to 1024 char
function migrateScopeFieldToVarchar1024(connection) {
    return tslib_1.__awaiter(this, void 0, void 0, function () {
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, connection.query("ALTER TABLE \"".concat(connection.sessionStorageIdentifier, "\"\n    ALTER COLUMN \"scope\" TYPE varchar(1024)"))];
                case 1:
                    _a.sent();
                    return [2 /*return*/];
            }
        });
    });
}
exports.migrateScopeFieldToVarchar1024 = migrateScopeFieldToVarchar1024;
function migrateToCaseSensitivity(connection) {
    return tslib_1.__awaiter(this, void 0, void 0, function () {
        var queries, hasOldColumnsQuery, rows, hasOldSessionTable, queries_1, queries_1_1, query, e_1_1, error_1;
        var e_1, _a;
        return tslib_1.__generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    queries = [];
                    if (!(connection.sessionStorageIdentifier ===
                        connection.sessionStorageIdentifier.toLowerCase())) return [3 /*break*/, 2];
                    hasOldColumnsQuery = "\n      SELECT EXISTS (\n        SELECT column_name FROM information_schema.columns\n        WHERE table_schema='public' AND table_name = '".concat(connection.sessionStorageIdentifier, "' AND column_name='isonline'\n      )\n    ");
                    return [4 /*yield*/, connection.query(hasOldColumnsQuery)];
                case 1:
                    rows = _b.sent();
                    if (rows[0].exists) {
                        queries = [
                            "ALTER TABLE \"".concat(connection.sessionStorageIdentifier, "\" RENAME COLUMN \"isonline\" TO \"isOnline\""),
                            "ALTER TABLE \"".concat(connection.sessionStorageIdentifier, "\" RENAME COLUMN \"onlineaccessinfo\" TO \"onlineAccessInfo\""),
                            "ALTER TABLE \"".concat(connection.sessionStorageIdentifier, "\" RENAME COLUMN \"accesstoken\" TO \"accessToken\""),
                        ];
                    }
                    return [3 /*break*/, 4];
                case 2: return [4 /*yield*/, connection.hasTable(connection.sessionStorageIdentifier.toLowerCase())];
                case 3:
                    hasOldSessionTable = _b.sent();
                    if (hasOldSessionTable) {
                        queries = [
                            // 1. copy the data from the old table to the new one
                            "INSERT INTO \"".concat(connection.sessionStorageIdentifier, "\" (\n          \"id\", \"shop\", \"state\", \"isOnline\", \"scope\", \"expires\", \"onlineAccessInfo\", \"accessToken\"\n        )\n        SELECT id, shop, state, isonline, scope, expires, onlineaccessinfo, accesstoken\n        FROM \"").concat(connection.sessionStorageIdentifier.toLowerCase(), "\""),
                            // 2. drop the old table
                            "DROP TABLE \"".concat(connection.sessionStorageIdentifier.toLowerCase(), "\""),
                        ];
                    }
                    _b.label = 4;
                case 4:
                    if (!(queries.length !== 0)) return [3 /*break*/, 16];
                    // wrap in a transaction
                    queries.unshift("BEGIN");
                    queries.push("COMMIT");
                    _b.label = 5;
                case 5:
                    _b.trys.push([5, 14, , 16]);
                    _b.label = 6;
                case 6:
                    _b.trys.push([6, 11, 12, 13]);
                    queries_1 = tslib_1.__values(queries), queries_1_1 = queries_1.next();
                    _b.label = 7;
                case 7:
                    if (!!queries_1_1.done) return [3 /*break*/, 10];
                    query = queries_1_1.value;
                    return [4 /*yield*/, connection.query(query)];
                case 8:
                    _b.sent();
                    _b.label = 9;
                case 9:
                    queries_1_1 = queries_1.next();
                    return [3 /*break*/, 7];
                case 10: return [3 /*break*/, 13];
                case 11:
                    e_1_1 = _b.sent();
                    e_1 = { error: e_1_1 };
                    return [3 /*break*/, 13];
                case 12:
                    try {
                        if (queries_1_1 && !queries_1_1.done && (_a = queries_1.return)) _a.call(queries_1);
                    }
                    finally { if (e_1) throw e_1.error; }
                    return [7 /*endfinally*/];
                case 13: return [3 /*break*/, 16];
                case 14:
                    error_1 = _b.sent();
                    // rollback if any of the queries fail
                    return [4 /*yield*/, connection.query("ROLLBACK")];
                case 15:
                    // rollback if any of the queries fail
                    _b.sent();
                    throw error_1;
                case 16: return [2 /*return*/];
            }
        });
    });
}
exports.migrateToCaseSensitivity = migrateToCaseSensitivity;
//# sourceMappingURL=migrations.js.map